@@ -1378,24 +1378,48 @@ static struct string *memdupzero(char *source, size_t len, bool *modified)
     else {
       int llen;
       int rlen;
+      int leftside;
+      int rightside;
 
       /* decode both sides */
-      left = decodequery(source, (int)(sep - source), &llen);
-      if(!left)
-        goto error;
-      right = decodequery(sep + 1,
-                          (int)len - (int)(sep - source) - 1, &rlen);
-      if(!right)
-        goto error;
-      /* encode both sides again */
-      el = encodequery(left, llen);
-      if(!el)
-        goto error;
-      er = encodequery(right, rlen);
-      if(!er)
-        goto error;
+      leftside = (int)(sep - source);
+      if(leftside) {
+        left = decodequery(source, leftside, &llen);
+        if(!left)
+          goto error;
+      }
+      else {
+        left = NULL;
+        llen = 0;
+      }
 
-      encode = curl_maprintf("%s=%s", el, er);
+      /* length on the right side of '=': */
+      rightside = (int)len - (int)(sep - source) - 1;
+
+      if(rightside) {
+        right = decodequery(sep + 1,
+                            (int)len - (int)(sep - source) - 1, &rlen);
+        if(!right)
+          goto error;
+      }
+      else {
+        right = NULL;
+        rlen = 0;
+      }
+
+      /* encode both sides again */
+      if(left) {
+        el = encodequery(left, llen);
+        if(!el)
+          goto error;
+      }
+      if(right) {
+        er = encodequery(right, rlen);
+        if(!er)
+          goto error;
+      }
+
+      encode = curl_maprintf("%s=%s", el ? el : "", er ? er : "");
       if(!encode)
         goto error;
     }
